Page 103 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 103

Home

    I.

    The man they chose to promote as a leader in
    Germany was Adolf Hitler. The conditions that would
    enable them to bring Hitler to power had already been
    established by the signing of the Treaty of Versailles that
    placed impossible reparations demands upon the German
    government as a result of World War I. British Foreign
    Secretary, Lord Curzon, who was a delegate to the
    conference at Versailles stated that, "this is no peace;
    this is only a truce for twenty years."* In exactly 20 years
    (1939) the war began.

    As a result of the treaty's demands for reparations,
    (269 billion marks) the German government resorted to
    inflation of the currency to comply. The resulting
    inflation (printing of unbacked currency) wiped out the
    middle class and brought economic collapse to the
    nation. The extent of this inflation was so great that a
    pound of butter that cost 3 German marks in 1918 cost
    six-trillion marks by 1923. Toward the end, 100 million

    party came to power in Germany.

    Hitler had two main supporters, Wall Street in the
    United States, and the I. G. Farben company in
    Germany. The I. G. Farben company was a beneficiary
    of the Dawes Plan, which was initiated in the United

    98

    The Secret Side of History

    the stage on both sides of the ocean to create World War

    marks would not even buy a box of matches. The crisis

    having been created, the solution was then offered, a

    man on a white horse to save the nation. Adolf Hitler

    was promoted as that man and eventually he and his Nazi